@@ -9,7 +9,7 @@ background = Image.new(200, 200)
 gc = Draw.new
 
 # Draw the text centered on the background
-gc.annotate(background, 0, 0, 0, 0, TEXT) do |gc|
+gc.annotate(background, 0, 0, 0, 0, TEXT) do
     gc.font_family = 'Verdana'
     gc.pointsize = 36
     gc.gravity = CenterGravity
