@@ -1,6 +1,6 @@
-/* $Id: rminfo.c,v 1.38 2006/05/27 21:05:59 rmagick Exp $ */
+/* $Id: rminfo.c,v 1.45.2.2.2.1 2007/09/30 22:10:22 rmagick Exp $ */
 /*============================================================================\
-|                Copyright (C) 2006 by Timothy P. Hunter
+|                Copyright (C) 2007 by Timothy P. Hunter
 | Name:     rminfo.c
 | Author:   Tim Hunter
 | Purpose:  Info class method definitions for RMagick.
@@ -92,7 +92,7 @@ Info_aset(VALUE self, VALUE format, VALUE key, VALUE value)
     key_p = STRING_PTR_LEN(key, key_l);
 
     /* Allow any argument that supports to_s */
-    value = rb_funcall(value, ID_to_s, 0);
+    value = rb_funcall(value, rm_ID_to_s, 0);
     value_p = STRING_PTR(value);
 
     if (format_l > MAX_FORMAT_LEN || format_l+key_l > MaxTextExtent-1)
@@ -125,7 +125,7 @@ Info_aset(VALUE self, VALUE format, VALUE key, VALUE value)
 
     format_p = STRING_PTR_LEN(format, format_l);
     key_p = STRING_PTR_LEN(key, key_l);
-    value = rb_funcall(value, ID_to_s, 0);
+    value = rb_funcall(value, rm_ID_to_s, 0);
     value_p = STRING_PTR_LEN(value, value_l);
 
     if ((3 + format_l + key_l + value_l) > sizeof(definitions))
@@ -141,7 +141,7 @@ Info_aset(VALUE self, VALUE format, VALUE key, VALUE value)
     GetExceptionInfo(&exception);
     okay = AddDefinitions(info, definitions, &exception);
     CHECK_EXCEPTION()
-    DestroyExceptionInfo(&exception);
+    (void) DestroyExceptionInfo(&exception);
 
     if (!okay)
     {
@@ -261,6 +261,39 @@ Info_border_color_eq(VALUE self, VALUE bc_arg)
     return self;
 }
 
+
+
+/*
+    Method:     Info#channel(channel [, channel...])
+    Purpose:    Set the channels
+    Thanks:     Douglas Sellers
+*/
+VALUE
+Info_channel(int argc, VALUE *argv, VALUE self)
+{
+#if defined(HAVE_IMAGEINFO_CHANNEL)
+    Info *info;
+    ChannelType channels;
+
+    channels = extract_channels(&argc, argv);
+
+    // Ensure all arguments consumed.
+    if (argc > 0)
+    {
+        raise_ChannelType_error(argv[argc-1]);
+    }
+
+    Data_Get_Struct(self, Info, info);
+
+    info->channel = channels;
+    return self;
+#else
+    rm_not_implemented();
+    return (VALUE)0;
+#endif
+}
+
+
 /*
     Method:     Info#colorspace
     Purpose:    Get the colorspace type
@@ -343,7 +376,7 @@ Info_define(int argc, VALUE *argv, VALUE self)
     {
         case 3:
             /* Allow any argument that supports to_s */
-            fmt_arg = rb_funcall(argv[2], ID_to_s, 0);
+            fmt_arg = rb_funcall(argv[2], rm_ID_to_s, 0);
             value = STRING_PTR(fmt_arg);
         case 2:
             key = STRING_PTR_LEN(argv[1], key_l);
@@ -385,7 +418,7 @@ Info_define(int argc, VALUE *argv, VALUE self)
     {
         case 3:
             /* Allow any argument that supports to_s */
-            fmt_arg = rb_funcall(argv[2], ID_to_s, 0);
+            fmt_arg = rb_funcall(argv[2], rm_ID_to_s, 0);
             value = STRING_PTR_LEN(fmt_arg, value_l);
             /* Fall through */
         case 2:
@@ -411,7 +444,7 @@ Info_define(int argc, VALUE *argv, VALUE self)
     GetExceptionInfo(&exception);
     okay = AddDefinitions(info, definitions, &exception);
     CHECK_EXCEPTION()
-    DestroyExceptionInfo(&exception);
+    (void) DestroyExceptionInfo(&exception);
 
     if (!okay)
     {
@@ -467,8 +500,7 @@ Info_delay(VALUE self)
 static VALUE
 arg_is_integer(VALUE arg)
 {
-    double d;
-    d = NUM2INT(arg);
+    int d = NUM2INT(arg);
     d = d;      // satisfy icc
     return arg;
 }
@@ -497,7 +529,7 @@ Info_delay_eq(VALUE self, VALUE string)
     else
     {
         not_num = 0;
-        rb_protect(arg_is_integer, string, &not_num);
+        (void) rb_protect(arg_is_integer, string, &not_num);
         if (not_num)
         {
             rb_raise(rb_eTypeError, "failed to convert %s into Integer", rb_class2name(CLASS_OF(string)));
@@ -536,7 +568,7 @@ Info_density_eq(VALUE self, VALUE density_arg)
         return self;
     }
 
-    density = rb_funcall(density_arg, ID_to_s, 0);
+    density = rb_funcall(density_arg, rm_ID_to_s, 0);
     dens = STRING_PTR(density);
     if (!IsGeometry(dens))
     {
@@ -559,10 +591,10 @@ VALUE
 Info_depth_eq(VALUE self, VALUE depth)
 {
     Info *info;
-    int d;
+    unsigned long d;
 
     Data_Get_Struct(self, Info, info);
-    d = NUM2INT(depth);
+    d = NUM2ULONG(depth);
     switch (d)
     {
         case 8:                     // always okay
@@ -574,7 +606,7 @@ Info_depth_eq(VALUE self, VALUE depth)
 #endif
             break;
         default:
-            rb_raise(rb_eArgError, "invalid depth (%d)", d);
+            rb_raise(rb_eArgError, "invalid depth (%lu)", d);
             break;
     }
 
@@ -712,7 +744,7 @@ Info_extract_eq(VALUE self, VALUE extract_arg)
         return self;
     }
 
-    extract = rb_funcall(extract_arg, ID_to_s, 0);
+    extract = rb_funcall(extract_arg, rm_ID_to_s, 0);
     extr = STRING_PTR(extract);
     if (!IsGeometry(extr))
     {
@@ -794,7 +826,7 @@ Info_tile_eq(VALUE self, VALUE tile_arg)
         return self;
     }
 
-    tile = rb_funcall(tile_arg, ID_to_s, 0);
+    tile = rb_funcall(tile_arg, rm_ID_to_s, 0);
     til = STRING_PTR(tile);
     if (!IsGeometry(til))
     {
@@ -854,10 +886,19 @@ Info_filename_eq(VALUE self, VALUE filename)
 VALUE
 Info_fill(VALUE self)
 {
+#if defined(HAVE_SETIMAGEOPTION)
+    Info *info;
+    const char *fill;
+
+    Data_Get_Struct(self, Info, info);
+    fill = GetImageOption(info, "fill");
+    return fill ? rb_str_new2(fill) : Qnil;
+#else
     Info *info;
 
     Data_Get_Struct(self, Info, info);
     return PixelPacket_to_Color_Name_Info(info, &info->pen);
+#endif
 }
 
 /*
@@ -872,6 +913,13 @@ Info_fill_eq(VALUE self, VALUE color)
 
     Data_Get_Struct(self, Info, info);
     Color_to_PixelPacket(&info->pen, color);
+
+#if defined(HAVE_SETIMAGEOPTION)
+    // Color_to_PixelPacket will raise an exception if `color' isn't a real color.
+    (void) RemoveImageOption(info, "fill");
+    (void) SetImageOption(info, "fill", STRING_PTR(color));
+#endif
+
     return self;
 }
 
@@ -918,7 +966,7 @@ VALUE Info_format(VALUE self)
     {
         GetExceptionInfo(&exception);
         magick_info = GetMagickInfo(info->magick, &exception);
-        DestroyExceptionInfo(&exception);
+        (void) DestroyExceptionInfo(&exception);
 
         return magick_info ? rb_str_new2(magick_info->name) : Qnil;
     }
@@ -945,7 +993,7 @@ Info_format_eq(VALUE self, VALUE magick)
     mgk = STRING_PTR(magick);
     m = GetMagickInfo(mgk, &exception);
     CHECK_EXCEPTION()
-    DestroyExceptionInfo(&exception);
+    (void) DestroyExceptionInfo(&exception);
 
     if (!m)
     {
@@ -1266,6 +1314,69 @@ Info_orientation_eq(VALUE self, VALUE inter)
 #endif
 }
 
+
+/*
+    Method:     Info#origin
+    Purpose:    Return origin geometry
+*/
+VALUE
+Info_origin(VALUE self)
+{
+#if defined(HAVE_SETIMAGEOPTION)
+    Info *info;
+    const char *origin;
+
+    Data_Get_Struct(self, Info, info);
+
+    origin = GetImageOption(info, "origin");
+    return origin ? rb_str_new2(origin) : Qnil;
+
+#else
+    rm_not_implemented();
+    return (VALUE)0;
+#endif
+}
+
+
+/*
+    Method:     Info#origin=+-x+-y
+    Purpose:    Set origin geometry. Argument may be a Geometry object as well
+                as a geometry string.
+*/
+VALUE
+Info_origin_eq(VALUE self, VALUE origin_arg)
+{
+#if defined(HAVE_SETIMAGEOPTION)
+    Info *info;
+    volatile VALUE origin_str;
+    char *origin;
+
+    Data_Get_Struct(self, Info, info);
+
+    if (NIL_P(origin_arg))
+    {
+        (void) RemoveImageOption(info, "origin");
+        return self;
+    }
+
+    origin_str = rb_funcall(origin_arg, rm_ID_to_s, 0);
+    origin = GetPageGeometry(STRING_PTR(origin_str));
+
+    if (IsGeometry(origin) == MagickFalse)
+    {
+        rb_raise(rb_eArgError, "invalid origin geometry: %s", origin);
+    }
+
+    (void) SetImageOption(info, "origin", origin);
+    return self;
+
+#else
+    rm_not_implemented();
+    return (VALUE)0;
+#endif
+}
+
+
 VALUE
 Info_page(VALUE self)
 {
@@ -1274,7 +1385,6 @@ Info_page(VALUE self)
 
     Data_Get_Struct(self, Info, info);
 #if defined(HAVE_SETIMAGEOPTION)
-
     page = GetImageOption(info, "page");
 #else
     page = (const char *)info->page;
@@ -1301,7 +1411,7 @@ Info_page_eq(VALUE self, VALUE page_arg)
         info->page = NULL;
         return self;
     }
-    geom_str = rb_funcall(page_arg, ID_to_s, 0);
+    geom_str = rb_funcall(page_arg, rm_ID_to_s, 0);
     geometry=GetPageGeometry(STRING_PTR(geom_str));
     if (*geometry == '\0')
     {
@@ -1318,7 +1428,7 @@ Info_page_eq(VALUE self, VALUE page_arg)
 }
 
 DEF_ATTR_ACCESSOR(Info, pointsize, dbl)
-DEF_ATTR_ACCESSOR(Info, quality, long)
+DEF_ATTR_ACCESSOR(Info, quality, ulong)
 
 /*
     Method:     Info#sampling_factor, #sampling_factor=
@@ -1499,7 +1609,7 @@ Info_size_eq(VALUE self, VALUE size_arg)
         return self;
     }
 
-    size = rb_funcall(size_arg, ID_to_s, 0);
+    size = rb_funcall(size_arg, rm_ID_to_s, 0);
     sz = STRING_PTR(size);
     if (!IsGeometry(sz))
     {
@@ -1512,6 +1622,43 @@ Info_size_eq(VALUE self, VALUE size_arg)
 }
 
 
+/*
+    Method:     Image::Info#texture=texture_image
+    Purpose:    Set name of texture to tile onto the image background
+*/
+VALUE
+Info_texture_eq(VALUE self, VALUE texture)
+{
+    Info *info;
+    Image *image;
+    char name[MaxTextExtent];
+
+    Data_Get_Struct(self, Info, info);
+
+    // Delete any existing texture file
+    if (info->texture)
+    {
+        rm_delete_temp_image(info->texture);
+        magick_free(info->texture);
+        info->texture = NULL;
+    }
+
+    // If argument is nil we're done
+    if (texture == Qnil)
+    {
+        return self;
+    }
+
+    // Create a temp copy of the texture and store its name in the texture field
+    Data_Get_Struct(texture, Image, image);
+    rm_write_temp_image(image, name);
+
+    magick_clone_string(&info->texture, name);
+
+    return self;
+}
+
+
 /*
     Method:     Info#undefine
     Purpose:    Undefine image option
@@ -1628,6 +1775,27 @@ Info_view_eq(VALUE self, VALUE view_arg)
     return self;
 }
 
+
+/*
+    Static:     destroy_Info
+    Purpose:    if there is a texture image, delete it before destroying
+                the ImageInfo structure
+*/
+static void
+destroy_Info(void *infoptr)
+{
+    Info *info = (Info *)infoptr;
+
+    if (info->texture)
+    {
+        rm_delete_temp_image(info->texture);
+        magick_free(info->texture);
+        info->texture = NULL;
+    }
+
+    (void) DestroyImageInfo(info);
+}
+
 /*
     Method:     Info.new
     Purpose:    Create an Info object by calling CloneInfo
@@ -1644,7 +1812,7 @@ Info_new(VALUE class)
     {
         rb_raise(rb_eNoMemError, "not enough memory to initialize Info object");
     }
-    new_obj = Data_Wrap_Struct(class, NULL, DestroyImageInfo, info);
+    new_obj = Data_Wrap_Struct(class, NULL, destroy_Info, info);
     rb_obj_call_init(new_obj, 0, NULL);
     return new_obj;
 }
@@ -1676,7 +1844,7 @@ Info_alloc(VALUE class)
     {
         rb_raise(rb_eNoMemError, "not enough memory to initialize Info object");
     }
-    info_obj = Data_Wrap_Struct(class, NULL, DestroyImageInfo, info);
+    info_obj = Data_Wrap_Struct(class, NULL, destroy_Info, info);
     return info_obj;
 }
 /*
@@ -1704,7 +1872,7 @@ Info_initialize(VALUE self)
     if (rb_block_given_p())
     {
         // Run the block in self's context
-        rb_obj_instance_eval(0, NULL, self);
+        (void) rb_obj_instance_eval(0, NULL, self);
     }
     return self;
 }
