@@ -1,6 +1,6 @@
-# $Id: RMagick.rb,v 1.43 2006/06/20 23:18:22 rmagick Exp $
+# $Id: RMagick.rb,v 1.51 2007/01/20 23:13:50 rmagick Exp $
 #==============================================================================
-#                  Copyright (C) 2006 by Timothy P. Hunter
+#                  Copyright (C) 2007 by Timothy P. Hunter
 #   Name:       RMagick.rb
 #   Author:     Tim Hunter
 #   Purpose:    Extend Ruby to interface with ImageMagick.
@@ -54,14 +54,14 @@ class Geometry
         elsif width.to_f >= 0.0
             @width = width.to_f
         else
-            raise ArgumentError, "width must be >= 0: #{width}"
+            Kernel.raise ArgumentError, "width must be >= 0: #{width}"
         end
         if height == nil
             @height = 0
         elsif height.to_f >= 0.0
             @height = height.to_f
         else
-            raise ArgumentError, "height must be >= 0: #{height}"
+            Kernel.raise ArgumentError, "height must be >= 0: #{height}"
         end
 
         @x    = x.to_i
@@ -73,7 +73,7 @@ class Geometry
     RE = /\A(\d*)(?:x(\d+))?([-+]\d+)?([-+]\d+)?([%!<>@]?)\Z/
 
     def Geometry.from_s(str)
-        raise(ArgumentError, "no geometry string specified") unless str
+        Kernel.raise(ArgumentError, "no geometry string specified") unless str
 
         m = RE.match(str)
         if m
@@ -83,7 +83,7 @@ class Geometry
             y      = m[4].to_i
             flag   = RFLAGS[m[5]]
         else
-            raise ArgumentError, "invalid geometry format"
+            Kernel.raise ArgumentError, "invalid geometry format"
         end
         Geometry.new(width, height, x, y, flag)
     end
@@ -108,25 +108,25 @@ class Draw
         LeftAlign.to_i => 'left',
         RightAlign.to_i => 'right',
         CenterAlign.to_i => 'center'
-        }
+        }.freeze
     ANCHOR_TYPE_NAMES = {
         StartAnchor.to_i => 'start',
         MiddleAnchor.to_i => 'middle',
         EndAnchor.to_i => 'end'
-        }
+        }.freeze
     DECORATION_TYPE_NAMES = {
         NoDecoration.to_i => 'none',
         UnderlineDecoration.to_i => 'underline',
         OverlineDecoration.to_i => 'overline',
         LineThroughDecoration.to_i => 'line-through'
-        }
+        }.freeze
     FONT_WEIGHT_NAMES = {
         AnyWeight.to_i => 'all',
         NormalWeight.to_i => 'normal',
         BoldWeight.to_i => 'bold',
         BolderWeight.to_i => 'bolder',
         LighterWeight.to_i => 'lighter',
-        }
+        }.freeze
     GRAVITY_NAMES = {
         NorthWestGravity.to_i => 'northwest',
         NorthGravity.to_i => 'north',
@@ -137,14 +137,14 @@ class Draw
         SouthWestGravity.to_i => 'southwest',
         SouthGravity.to_i => 'south',
         SouthEastGravity.to_i => 'southeast'
-        }
+        }.freeze
     PAINT_METHOD_NAMES = {
         PointMethod.to_i => 'point',
         ReplaceMethod.to_i => 'replace',
         FloodfillMethod.to_i => 'floodfill',
         FillToBorderMethod.to_i => 'filltoborder',
         ResetMethod.to_i => 'reset'
-        }
+        }.freeze
     STRETCH_TYPE_NAMES = {
         NormalStretch.to_i => 'normal',
         UltraCondensedStretch.to_i => 'ultra-condensed',
@@ -156,13 +156,13 @@ class Draw
         ExtraExpandedStretch.to_i => 'extra-expanded',
         UltraExpandedStretch.to_i => 'ultra-expanded',
         AnyStretch.to_i => 'all'
-        }
+        }.freeze
     STYLE_TYPE_NAMES = {
         NormalStyle.to_i => 'normal',
         ItalicStyle.to_i => 'italic',
         ObliqueStyle.to_i => 'oblique',
         AnyStyle.to_i => 'all'
-        }
+        }.freeze
 
   private
     def enquote(str)
@@ -190,9 +190,9 @@ class Draw
     # Draw a bezier curve.
     def bezier(*points)
         if points.length == 0
-            raise ArgumentError, "no points specified"
+            Kernel.raise ArgumentError, "no points specified"
         elsif points.length % 2 != 0
-            raise ArgumentError, "odd number of arguments specified"
+            Kernel.raise ArgumentError, "odd number of arguments specified"
         end
         primitive "bezier " + points.join(',')
     end
@@ -210,7 +210,7 @@ class Draw
     # Define the clipping rule.
     def clip_rule(rule)
         if ( not ["evenodd", "nonzero"].include?(rule.downcase) )
-            raise ArgumentError, "Unknown clipping rule #{rule}"
+            Kernel.raise ArgumentError, "Unknown clipping rule #{rule}"
         end
         primitive "clip-rule #{rule}"
     end
@@ -218,7 +218,7 @@ class Draw
     # Define the clip units
     def clip_units(unit)
         if ( not ["userspace", "userspaceonuse", "objectboundingbox"].include?(unit.downcase) )
-            raise ArgumentError, "Unknown clip unit #{unit}"
+            Kernel.raise ArgumentError, "Unknown clip unit #{unit}"
         end
         primitive "clip-units #{unit}"
     end
@@ -227,7 +227,7 @@ class Draw
     # point, replace, floodfill, filltoborder,reset
     def color(x, y, method)
         if ( not PAINT_METHOD_NAMES.has_key?(method.to_i) )
-            raise ArgumentError, "Unknown PaintMethod: #{method}"
+            Kernel.raise ArgumentError, "Unknown PaintMethod: #{method}"
         end
         primitive "color #{x},#{y},#{PAINT_METHOD_NAMES[method.to_i]}"
     end
@@ -286,7 +286,7 @@ class Draw
 
     def fill_rule(rule)
         if ( not ["evenodd", "nonzero"].include?(rule.downcase) )
-            raise ArgumentError, "Unknown fill rule #{rule}"
+            Kernel.raise ArgumentError, "Unknown fill rule #{rule}"
         end
         primitive "fill-rule #{rule}"
     end
@@ -302,14 +302,14 @@ class Draw
 
     def font_stretch(stretch)
         if ( not STRETCH_TYPE_NAMES.has_key?(stretch.to_i) )
-            raise ArgumentError, "Unknown stretch type"
+            Kernel.raise ArgumentError, "Unknown stretch type"
         end
         primitive "font-stretch #{STRETCH_TYPE_NAMES[stretch.to_i]}"
     end
 
     def font_style(style)
         if ( not STYLE_TYPE_NAMES.has_key?(style.to_i) )
-            raise ArgumentError, "Unknown style type"
+            Kernel.raise ArgumentError, "Unknown style type"
         end
         primitive "font-style #{STYLE_TYPE_NAMES[style.to_i]}"
     end
@@ -328,7 +328,7 @@ class Draw
     # NorthWest, North, NorthEast, West, Center, East, SouthWest, South, SouthEast
     def gravity(grav)
         if ( not GRAVITY_NAMES.has_key?(grav.to_i) )
-            raise ArgumentError, "Unknown text positioning gravity"
+            Kernel.raise ArgumentError, "Unknown text positioning gravity"
         end
         primitive "gravity #{GRAVITY_NAMES[grav.to_i]}"
     end
@@ -340,9 +340,9 @@ class Draw
 
     # Set matte (make transparent) in image according to the specified
     # colorization rule
-    def matte(x, y, rule)
+    def matte(x, y, method)
         if ( not PAINT_METHOD_NAMES.has_key?(method.to_i) )
-            raise ArgumentError, "Unknown paint method"
+            Kernel.raise ArgumentError, "Unknown paint method"
         end
         primitive "matte #{x},#{y} #{PAINT_METHOD_NAMES[method.to_i]}"
     end
@@ -352,7 +352,7 @@ class Draw
     def opacity(opacity)
         if (Numeric === opacity)
             if (opacity < 0 || opacity > 1.0)
-                raise ArgumentError, "opacity must be >= 0 and <= 1.0"
+                Kernel.raise ArgumentError, "opacity must be >= 0 and <= 1.0"
             end
         end
         primitive "opacity #{opacity}"
@@ -396,9 +396,9 @@ class Draw
     # Draw a polygon
     def polygon(*points)
         if points.length == 0
-            raise ArgumentError, "no points specified"
+            Kernel.raise ArgumentError, "no points specified"
         elsif points.length % 2 != 0
-            raise ArgumentError, "odd number of points specified"
+            Kernel.raise ArgumentError, "odd number of points specified"
         end
         primitive "polygon " + points.join(',')
     end
@@ -406,9 +406,9 @@ class Draw
     # Draw a polyline
     def polyline(*points)
         if points.length == 0
-            raise ArgumentError, "no points specified"
+            Kernel.raise ArgumentError, "no points specified"
         elsif points.length % 2 != 0
-            raise ArgumentError, "odd number of points specified"
+            Kernel.raise ArgumentError, "odd number of points specified"
         end
         primitive "polyline " + points.join(',')
     end
@@ -492,7 +492,7 @@ class Draw
         else
             list.each { |x|
                 if x <= 0 then
-                    raise ArgumentError, "dash array elements must be > 0 (#{x} given)"
+                    Kernel.raise ArgumentError, "dash array elements must be > 0 (#{x} given)"
                 end
             }
             primitive "stroke-dasharray #{list.join(',')}"
@@ -506,21 +506,21 @@ class Draw
 
     def stroke_linecap(value)
         if ( not ["butt", "round", "square"].include?(value.downcase) )
-            raise ArgumentError, "Unknown linecap type: #{value}"
+            Kernel.raise ArgumentError, "Unknown linecap type: #{value}"
         end
         primitive "stroke-linecap #{value}"
     end
 
     def stroke_linejoin(value)
         if ( not ["round", "miter", "bevel"].include?(value.downcase) )
-            raise ArgumentError, "Unknown linejoin type: #{value}"
+            Kernel.raise ArgumentError, "Unknown linejoin type: #{value}"
         end
         primitive "stroke-linejoin #{value}"
     end
 
     def stroke_miterlimit(value)
         if (value < 1)
-            raise ArgumentError, "miterlimit must be >= 1"
+            Kernel.raise ArgumentError, "miterlimit must be >= 1"
         end
         primitive "stroke-miterlimit #{value}"
     end
@@ -539,7 +539,7 @@ class Draw
     # Draw text at position x,y. Add quotes to text that is not already quoted.
     def text(x, y, text)
         if text.to_s.empty?
-            raise ArgumentError, "missing text argument"
+            Kernel.raise ArgumentError, "missing text argument"
         end
         if text.length > 2 && /\A(?:\"[^\"]+\"|\'[^\']+\'|\{[^\}]+\})\z/.match(text)
             ; # text already quoted
@@ -559,7 +559,7 @@ class Draw
     # Specify text alignment relative to a given point
     def text_align(alignment)
         if ( not ALIGN_TYPE_NAMES.has_key?(alignment.to_i) )
-            raise ArgumentError, "Unknown alignment constant: #{alignment}"
+            Kernel.raise ArgumentError, "Unknown alignment constant: #{alignment}"
         end
         primitive "text-align #{ALIGN_TYPE_NAMES[alignment.to_i]}"
     end
@@ -567,7 +567,7 @@ class Draw
     # SVG-compatible version of text_align
     def text_anchor(anchor)
         if ( not ANCHOR_TYPE_NAMES.has_key?(anchor.to_i) )
-            raise ArgumentError, "Unknown anchor constant: #{anchor}"
+            Kernel.raise ArgumentError, "Unknown anchor constant: #{anchor}"
         end
         primitive "text-anchor #{ANCHOR_TYPE_NAMES[anchor.to_i]}"
     end
@@ -590,6 +590,115 @@ class Draw
     end
 end # class Magick::Draw
 
+
+# Define IPTC record number:dataset tags for use with Image#get_iptc_dataset
+module IPTC
+    module Envelope
+        Model_Version                          = "1:00"
+        Destination                            = "1:05"
+        File_Format                            = "1:20"
+        File_Format_Version                    = "1:22"
+        Service_Identifier                     = "1:30"
+        Envelope_Number                        = "1:40"
+        Product_ID                             = "1:50"
+        Envelope_Priority                      = "1:60"
+        Date_Sent                              = "1:70"
+        Time_Sent                              = "1:80"
+        Coded_Character_Set                    = "1:90"
+        UNO                                    = "1:100"
+        Unique_Name_of_Object                  = "1:100"
+        ARM_Identifier                         = "1:120"
+        ARM_Version                            = "1:122"
+    end
+
+    module Application
+       #Record_Version                         = "2:00" abends with IM 6.2.9
+        Object_Type_Reference                  = "2:03"
+        Object_Name                            = "2:05"
+        Title                                  = "2:05"
+        Edit_Status                            = "2:07"
+        Editorial_Update                       = "2:08"
+        Urgency                                = "2:10"
+        Subject_Reference                      = "2:12"
+        Category                               = "2:15"
+        Supplemental_Category                  = "2:20"
+        Fixture_Identifier                     = "2:22"
+        Keywords                               = "2:25"
+        Content_Location_Code                  = "2:26"
+        Content_Location_Name                  = "2:27"
+        Release_Date                           = "2:30"
+        Release_Time                           = "2:35"
+        Expiration_Date                        = "2:37"
+        Expiration_Time                        = "2:35"
+        Special_Instructions                   = "2:40"
+        Action_Advised                         = "2:42"
+        Reference_Service                      = "2:45"
+        Reference_Date                         = "2:47"
+        Reference_Number                       = "2:50"
+        Date_Created                           = "2:55"
+        Time_Created                           = "2:60"
+        Digital_Creation_Date                  = "2:62"
+        Digital_Creation_Time                  = "2:63"
+        Originating_Program                    = "2:65"
+        Program_Version                        = "2:70"
+        Object_Cycle                           = "2:75"
+        By_Line                                = "2:80"
+        Author                                 = "2:80"
+        By_Line_Title                          = "2:85"
+        Author_Position                        = "2:85"
+        City                                   = "2:90"
+        Sub_Location                           = "2:92"
+        Province                               = "2:95"
+        State                                  = "2:95"
+        Country_Primary_Location_Code          = "2:100"
+        Country_Primary_Location_Name          = "2:101"
+        Original_Transmission_Reference        = "2:103"
+        Headline                               = "2:105"
+        Credit                                 = "2:110"
+        Source                                 = "2:115"
+        Copyright_Notice                       = "2:116"
+        Contact                                = "2:118"
+        Abstract                               = "2:120"
+        Caption                                = "2:120"
+        Editor                                 = "2:122"
+        Caption_Writer                         = "2:122"
+        Rasterized_Caption                     = "2:125"
+        Image_Type                             = "2:130"
+        Image_Orientation                      = "2:131"
+        Language_Identifier                    = "2:135"
+        Audio_Type                             = "2:150"
+        Audio_Sampling_Rate                    = "2:151"
+        Audio_Sampling_Resolution              = "2:152"
+        Audio_Duration                         = "2:153"
+        Audio_Outcue                           = "2:154"
+        ObjectData_Preview_File_Format         = "2:200"
+        ObjectData_Preview_File_Format_Version = "2:201"
+        ObjectData_Preview_Data                = "2:202"
+    end
+
+    module Pre_ObjectData_Descriptor
+        Size_Mode                              = "7:10"
+        Max_Subfile_Size                       = "7:20"
+        ObjectData_Size_Announced              = "7:90"
+        Maximum_ObjectData_Size                = "7:95"
+    end
+
+    module ObjectData
+        Subfile                                = "8:10"
+    end
+
+    module Post_ObjectData_Descriptor
+        Confirmed_ObjectData_Size              = "9:10"
+    end
+
+    # Make all constants above immutable
+    constants.each do |record|
+        rec = const_get(record)
+        rec.constants.each { |ds| rec.const_get(ds).freeze }
+    end
+
+end # module Magick::IPTC
+
 # Ruby-level Magick::Image methods
 class Image
     include Comparable
@@ -698,6 +807,24 @@ class Image
         return hash
     end
 
+    # Retrieve IPTC information by record number:dataset tag constant defined in
+    # Magick::IPTC, above.
+    def get_iptc_dataset(ds)
+        self['IPTC:'+ds]
+    end
+
+    # Iterate over IPTC record number:dataset tags, yield for each non-nil dataset
+    def each_iptc_dataset
+        Magick::IPTC.constants.each do |record|
+            rec = Magick::IPTC.const_get(record)
+            rec.constants.each do |dataset|
+                data_field = get_iptc_dataset(rec.const_get(dataset))
+                yield(dataset, data_field) unless data_field.nil?
+            end
+        end
+        nil
+    end
+
     # Patches problematic change to the order of arguments in 1.11.0.
     # Before this release, the order was
     #       black_point, gamma, white_point
@@ -778,6 +905,16 @@ class Image
         self
     end
 
+    # Corresponds to ImageMagick's -resample option
+    def resample(x_res=72.0, y_res=nil)
+        y_res ||= x_res
+        width = x_res * columns / x_resolution + 0.5
+        height = y_res * rows / y_resolution + 0.5
+        self.x_resolution = x_res
+        self.y_resolution = y_res
+        resize(width, height)
+    end
+
     # Convenience method to resize retaining the aspect ratio.
     # (Thanks to Robert Manni!)
     def resize_to_fit(cols, rows)
@@ -827,10 +964,10 @@ class Image
 
         def initialize(img, x, y, width, height)
             if width <= 0 || height <= 0
-                raise ArgumentError, "invalid geometry (#{width}x#{height}+#{x}+#{y})"
+                Kernel.raise ArgumentError, "invalid geometry (#{width}x#{height}+#{x}+#{y})"
             end
             if x < 0 || y < 0 || (x+width) > img.columns || (y+height) > img.rows
-                raise RangeError, "geometry (#{width}x#{height}+#{x}+#{y}) exceeds image boundary"
+                Kernel.raise RangeError, "geometry (#{width}x#{height}+#{x}+#{y}) exceeds image boundary"
             end
             @view = img.get_pixels(x, y, width, height)
             @img = img
@@ -918,7 +1055,7 @@ class Image
                     begin
                         rv = Pixel.from_color(rv)
                     rescue TypeError
-                        raise TypeError, "cannot convert #{rv.class} into Pixel"
+                        Kernel.raise TypeError, "cannot convert #{rv.class} into Pixel"
                     end
                 end
                 cols(args)
@@ -957,7 +1094,7 @@ class Image
                                 @rows += @height
                             end
                             if @rows < 0 || @rows > @height-1
-                                raise IndexError, "index [#{@rows}] out of range"
+                                Kernel.raise IndexError, "index [#{@rows}] out of range"
                             end
                             # Convert back to an array
                             @rows = Array.new(1, @rows)
@@ -974,7 +1111,7 @@ class Image
                         end
 
                         if start > @height || start < 0 || length < 0
-                                raise IndexError, "index [#{@rows.first}] out of range"
+                                Kernel.raise IndexError, "index [#{@rows.first}] out of range"
                         else
                             if start + length > @height
                                 length = @height - length
@@ -1001,7 +1138,7 @@ class Image
                                 @cols += @width
                             end
                             if @cols < 0 || @cols > @width-1
-                                raise IndexError, "index [#{@cols}] out of range"
+                                Kernel.raise IndexError, "index [#{@cols}] out of range"
                             end
                             # Convert back to array
                             @cols = Array.new(1, @cols)
@@ -1039,11 +1176,11 @@ class Image
 
                 @rows.each do |j|
                     if j > maxrows
-                        raise IndexError, "index [#{j}] out of range"
+                        Kernel.raise IndexError, "index [#{j}] out of range"
                     end
                     @cols.each do |i|
                         if i > maxcols
-                            raise IndexError, "index [#{i}] out of range"
+                            Kernel.raise IndexError, "index [#{i}] out of range"
                         end
                         yield j*@width + i
                     end
@@ -1076,7 +1213,7 @@ protected
 
     def is_a_image(obj)
         unless obj.kind_of? Magick::Image
-            raise ArgumentError, "Magick::Image required (#{obj.class} given)"
+            Kernel.raise ArgumentError, "Magick::Image required (#{obj.class} given)"
         end
         true
     end
@@ -1084,7 +1221,7 @@ protected
     # Ensure array is always an array of Magick::Image objects
     def is_a_image_array(ary)
         unless ary.respond_to? :each
-            raise ArgumentError, "Magick::ImageList or array of Magick::Images required (#{ary.class} given)"
+            Kernel.raise ArgumentError, "Magick::ImageList or array of Magick::Images required (#{ary.class} given)"
         end
         ary.each { |obj| is_a_image obj }
         true
@@ -1116,16 +1253,16 @@ public
     # Allow scene to be set to nil
     def scene=(n)
         if n.nil?
-            raise IndexError, "scene number out of bounds" unless length == 0
+            Kernel.raise IndexError, "scene number out of bounds" unless length == 0
             @scene = nil
             return @scene
         elsif length == 0
-            raise IndexError, "scene number out of bounds"
+            Kernel.raise IndexError, "scene number out of bounds"
         end
 
         n = Integer(n)
         if n < 0 || n > length - 1
-            raise IndexError, "scene number out of bounds"
+            Kernel.raise IndexError, "scene number out of bounds"
         end
         @scene = n
         return @scene
@@ -1172,7 +1309,7 @@ public
 
     def *(n)
         unless n.kind_of? Integer
-            raise ArgumentError, "Integer required (#{n.class} given)"
+            Kernel.raise ArgumentError, "Integer required (#{n.class} given)"
         end
         cfid = self[@scene].__id__ rescue nil
         a = self.class.new.replace super
@@ -1289,7 +1426,7 @@ public
 
     if self.superclass.instance_methods(true).include? 'insert' then
         def insert(*args)
-            raise(ArgumentError, "can't insert nil") unless args.length > 1
+            Kernel.raise(ArgumentError, "can't insert nil") unless args.length > 1
             is_a_image_array args[1,args.length-1]
             cfid = self[@scene].__id__ rescue nil
             super
@@ -1439,7 +1576,7 @@ public
     #   return A.length <=> B.length
     def <=>(other)
         unless other.kind_of? self.class
-           raise TypeError, "#{self.class} required (#{other.class} given)"
+           Kernel.raise TypeError, "#{self.class} required (#{other.class} given)"
         end
         size = [self.length, other.length].min
         size.times do |x|
@@ -1449,9 +1586,9 @@ public
         if @scene.nil? && other.scene.nil?
             return 0
         elsif @scene.nil? && ! other.scene.nil?
-            raise TypeError, "cannot convert nil into #{other.scene.class}"
+            Kernel.raise TypeError, "cannot convert nil into #{other.scene.class}"
         elsif ! @scene.nil? && other.scene.nil?
-            raise TypeError, "cannot convert nil into #{self.scene.class}"
+            Kernel.raise TypeError, "cannot convert nil into #{self.scene.class}"
         end
         r = self.scene <=> other.scene
         return r unless r == 0
@@ -1476,7 +1613,7 @@ public
     # Return the current image
     def cur_image
         if ! @scene
-            raise IndexError, "no images in this list"
+            Kernel.raise IndexError, "no images in this list"
         end
         self[@scene]
     end
@@ -1491,7 +1628,7 @@ public
 
     def ticks_per_second=(t)
         if Integer(t) < 0
-            raise ArgumentError, "ticks_per_second must be greater than or equal to 0"
+            Kernel.raise ArgumentError, "ticks_per_second must be greater than or equal to 0"
         end
         each { |f| f.ticks_per_second = Integer(t) }
     end
@@ -1506,7 +1643,7 @@ public
 
     def from_blob(*blobs, &block)
         if (blobs.length == 0)
-            raise ArgumentError, "no blobs given"
+            Kernel.raise ArgumentError, "no blobs given"
         end
         blobs.each { |b|
             Magick::Image.from_blob(b, &block).each { |n| self << n  }
@@ -1538,7 +1675,7 @@ public
     def iterations=(n)
         n = Integer(n)
         if n < 0 || n > 65535
-            raise ArgumentError, "iterations must be between 0 and 65535"
+            Kernel.raise ArgumentError, "iterations must be between 0 and 65535"
         end
         each {|f| f.iterations=n}
         self
@@ -1556,10 +1693,10 @@ public
                 super
             end
         rescue NoMethodError
-          raise NoMethodError, "undefined method `#{methID.id2name}' for #{self.class}"
+          Kernel.raise NoMethodError, "undefined method `#{methID.id2name}' for #{self.class}"
         rescue Exception
             $@.delete_if { |s| /:in `send'$/.match(s) || /:in `method_missing'$/.match(s) }
-            raise
+            Kernel.raise
         end
     end
 
@@ -1582,7 +1719,7 @@ public
     # Ping files and concatenate the new images
     def ping(*files, &block)
         if (files.length == 0)
-            raise ArgumentError, "no files given"
+            Kernel.raise ArgumentError, "no files given"
         end
         files.each { |f|
             Magick::Image.ping(f, &block).each { |n| self << n }
@@ -1594,7 +1731,7 @@ public
     # Read files and concatenate the new images
     def read(*files, &block)
         if (files.length == 0)
-            raise ArgumentError, "no files given"
+            Kernel.raise ArgumentError, "no files given"
         end
         files.each { |f|
             Magick::Image.read(f, &block).each { |n| self << n }
